==> react-date-range-ts-1.6.0.tgz: package/src/components/StaticRanges/index.tsx <==
import React, { useState } from 'react';
import styles, { DEFAULT_COLOR } from '../../styles';
import { defaultInputRangesGen, defaultStaticRangesGen } from '../../defaultRanges';
import { InputRangeWihLabel, isSureRange, NotFullyEmptyRange, OtherRangeProps, MaybeEmptyRange, RangeFocus, StaticRange, WeekStartsOn, ClearPreview, PreviewRange, OnRangeChangeHandler } from '../../types';
import { defaultInputRanges, defaultStaticRanges, DEFAULT_WEEK_STARTS_ON } from '../../defaultRanges';

import StaticRangeButton from './StaticRangeButton';

export type StaticRangesHandleRangeChangeProps = {
  focusedRange?: RangeFocus;
  // onChange?: (keyedRange: { [k: string]: MaybeEmptyRange; }) => void;
  onChange?: OnRangeChangeHandler;
  ranges?: NotFullyEmptyRange[];
};

type ComponentProps = StaticRangesHandleRangeChangeProps & {
  className?: string;
  footerContent?: JSX.Element;
  handleRangeChange?: ReturnType<typeof handleRangeChangeGen>
  headerContent?: JSX.Element;
  inputRanges?: InputRangeWihLabel[];
  onPreviewChange?: (r?: PreviewRange | ClearPreview) => void;
  rangeColors?: string[];
  renderStaticRangeLabel?: (r: StaticRange) => JSX.Element;
  staticRanges?: StaticRange[];
  weekStartsOn?: WeekStartsOn;
}
export type DefinedRangeCP = ComponentProps;

type DefaultComponentProps = StaticRangesInputRanges & {
  ranges: NotFullyEmptyRange[];
  rangeColors: string[];
  focusedRange: RangeFocus;
  weekStartsOn: WeekStartsOn;
};
export type StaticRangeDCP = DefaultComponentProps;

const defaultProps: DefaultComponentProps = {
  ranges: [],
  staticRanges: defaultStaticRanges,
  inputRanges: defaultInputRanges,
  rangeColors: [DEFAULT_COLOR, '#3ecf8e', '#fed14c'],
  focusedRange: [0, 0],
  weekStartsOn: DEFAULT_WEEK_STARTS_ON,
};

type StaticRangesInputRanges = {
  staticRanges: StaticRange[];
  inputRanges: InputRangeWihLabel[];
}

function getSelectedRangeIndex(ranges: MaybeEmptyRange[], staticRanges: StaticRange[]) {
  return staticRanges.reduce((p, staticRange, sidx) => {
    const focusedRangeIndex = ranges.findIndex(range => {
      if (!isSureRange<OtherRangeProps>(range) || range.disabled) return false;
      return staticRange.isSelected(range);
    });
    if (focusedRangeIndex < 0) {
      return p;
    }
    return { staticRangeIndex: sidx, focusedRangeIndex };
  }, { staticRangeIndex: -1, focusedRangeIndex: -1 });
}

function getSelectedRange(ranges: MaybeEmptyRange[], staticRange: StaticRange) {
    const focusedRangeIndex = ranges.findIndex(range => {
      if (!isSureRange<OtherRangeProps>(range) || range.disabled) return false;
      return staticRange.isSelected(range);
    });
    const selectedRange = ranges[focusedRangeIndex];
    return { selectedRange, focusedRangeIndex };
}

export const handleRangeChangeGen = (allProps: StaticRangesHandleRangeChangeProps) => (range: MaybeEmptyRange) => {
  const { onChange, ranges, focusedRange } = allProps;
  const frange = focusedRange || [0, 0];
  const selectedRange = ranges && ranges[frange[0]];
  if (!onChange || !selectedRange) return;
  onChange({
    [selectedRange.key || `range${frange[0] + 1}`]: { ...selectedRange, ...range },
  }, frange[1] === 0);
}


const StaticRanges: React.FC<ComponentProps> = (props) => {
  const allProps: ComponentProps = { ...defaultProps, ...props };

  const weekStartsOn = allProps.weekStartsOn !== undefined && allProps.weekStartsOn || DEFAULT_WEEK_STARTS_ON;
  const [rangesRespectingWeekStartsOn,] = useState<StaticRangesInputRanges>((allProps.weekStartsOn !== undefined && allProps.weekStartsOn !== DEFAULT_WEEK_STARTS_ON)
    ? {
      staticRanges: defaultStaticRangesGen({ weekStartsOn }),
      inputRanges: defaultInputRangesGen({ weekStartsOn }),
    }
    : {
      staticRanges: allProps.staticRanges || defaultStaticRanges,
      inputRanges: allProps.inputRanges || defaultInputRanges,
    }
  );

  const {
    handleRangeChange,
    onPreviewChange,
    rangeColors,
    ranges,
    renderStaticRangeLabel,
  } = allProps;

  const {
    staticRanges,
  } = rangesRespectingWeekStartsOn;

  const usableHandleRangeChange = handleRangeChange || handleRangeChangeGen(allProps);

  const { staticRangeIndex } = getSelectedRangeIndex(ranges || [], staticRanges);

  return (
    <div className={styles.staticRangesWrapper}>
      <div className={styles.staticRanges}>
        {staticRanges.map((staticRange, i) => {
          const { selectedRange, focusedRangeIndex } = getSelectedRange(ranges || [], staticRange);
          console.log('selectedRange, ', selectedRange, focusedRangeIndex);
          return (
            <StaticRangeButton
              key={i}
              onPreviewChange={onPreviewChange}
              rangeColors={rangeColors}
              renderStaticRangeLabel={renderStaticRangeLabel}
              selectedRange={selectedRange}
              focusedRangeIndex={focusedRangeIndex}
              staticRange={staticRange}
              handleRangeChange={usableHandleRangeChange}
            />
          );
        })}
        {staticRangeIndex === -1
          ? <span key={"custom-range"} className={styles.staticRangeCustomSelection}>Custom</span>
          : null
        }
      </div>
    </div>
  );
}

export default StaticRanges;

==> react-date-range-ts-1.6.1.tgz: package/src/components/StaticRanges/index.tsx <==
import React, { useState } from 'react';
import styles, { DEFAULT_COLOR } from '../../styles';
import { defaultInputRangesGen, defaultStaticRangesGen, REFERENCE_DATE } from '../../defaultRanges';
import { InputRangeWihLabel, isSureRange, NotFullyEmptyRange, OtherRangeProps, MaybeEmptyRange, RangeFocus, StaticRange, WeekStartsOn, ClearPreview, PreviewRange, OnRangeChangeHandler } from '../../types';
import { defaultInputRanges, defaultStaticRanges, DEFAULT_WEEK_STARTS_ON } from '../../defaultRanges';

import StaticRangeButton from './StaticRangeButton';

export type StaticRangesHandleRangeChangeProps = {
  focusedRange?: RangeFocus;
  // onChange?: (keyedRange: { [k: string]: MaybeEmptyRange; }) => void;
  onChange?: OnRangeChangeHandler;
  ranges?: NotFullyEmptyRange[];
};

type ComponentProps = StaticRangesHandleRangeChangeProps & {
  className?: string;
  footerContent?: JSX.Element;
  handleRangeChange?: ReturnType<typeof handleRangeChangeGen>
  headerContent?: JSX.Element;
  inputRanges?: InputRangeWihLabel[];
  onPreviewChange?: (r?: PreviewRange | ClearPreview) => void;
  rangeColors?: string[];
  renderStaticRangeLabel?: (r: StaticRange) => JSX.Element;
  staticRanges?: StaticRange[];
  weekStartsOn?: WeekStartsOn;
}
export type DefinedRangeCP = ComponentProps;

type DefaultComponentProps = StaticRangesInputRanges & {
  ranges: NotFullyEmptyRange[];
  rangeColors: string[];
  focusedRange: RangeFocus;
  weekStartsOn: WeekStartsOn;
};
export type StaticRangeDCP = DefaultComponentProps;

const defaultProps: DefaultComponentProps = {
  ranges: [],
  staticRanges: defaultStaticRanges,
  inputRanges: defaultInputRanges,
  rangeColors: [DEFAULT_COLOR, '#3ecf8e', '#fed14c'],
  focusedRange: [0, 0],
  weekStartsOn: DEFAULT_WEEK_STARTS_ON,
};

type StaticRangesInputRanges = {
  staticRanges: StaticRange[];
  inputRanges: InputRangeWihLabel[];
}

function getSelectedRangeIndex(ranges: MaybeEmptyRange[], staticRanges: StaticRange[]) {
  return staticRanges.reduce((p, staticRange, sidx) => {
    const focusedRangeIndex = ranges.findIndex(range => {
      if (!isSureRange<OtherRangeProps>(range) || range.disabled) return false;
      return staticRange.isSelected(range);
    });
    if (focusedRangeIndex < 0) {
      return p;
    }
    return { staticRangeIndex: sidx, focusedRangeIndex };
  }, { staticRangeIndex: -1, focusedRangeIndex: -1 });
}

function getSelectedRange(ranges: MaybeEmptyRange[], staticRange: StaticRange) {
    const focusedRangeIndex = ranges.findIndex(range => {
      if (!isSureRange<OtherRangeProps>(range) || range.disabled) return false;
      return staticRange.isSelected(range);
    });
    const selectedRange = ranges[focusedRangeIndex];
    return { selectedRange, focusedRangeIndex };
}

export const handleRangeChangeGen = (allProps: StaticRangesHandleRangeChangeProps) => (range: MaybeEmptyRange) => {
  const { onChange, ranges, focusedRange } = allProps;
  const frange = focusedRange || [0, 0];
  const selectedRange = ranges && ranges[frange[0]];
  if (!onChange || !selectedRange) return;
  onChange({
    [selectedRange.key || `range${frange[0] + 1}`]: { ...selectedRange, ...range },
  }, frange[1] === 0);
}


const StaticRanges: React.FC<ComponentProps> = (props) => {
  const allProps: ComponentProps = { ...defaultProps, ...props };

  const weekStartsOn = allProps.weekStartsOn !== undefined && allProps.weekStartsOn || DEFAULT_WEEK_STARTS_ON;
  const [rangesRespectingWeekStartsOn,] = useState<StaticRangesInputRanges>((allProps.weekStartsOn !== undefined && allProps.weekStartsOn !== DEFAULT_WEEK_STARTS_ON)
    ? {
      staticRanges: defaultStaticRangesGen({ weekStartsOn, referenceDate: REFERENCE_DATE || new Date() }),
      inputRanges: defaultInputRangesGen({ weekStartsOn, referenceDate: REFERENCE_DATE || new Date() }),
    }
    : {
      staticRanges: allProps.staticRanges || defaultStaticRanges,
      inputRanges: allProps.inputRanges || defaultInputRanges,
    }
  );

  const {
    handleRangeChange,
    onPreviewChange,
    rangeColors,
    ranges,
    renderStaticRangeLabel,
  } = allProps;

  const {
    staticRanges,
  } = rangesRespectingWeekStartsOn;

  const usableHandleRangeChange = handleRangeChange || handleRangeChangeGen(allProps);

  const { staticRangeIndex } = getSelectedRangeIndex(ranges || [], staticRanges);

  return (
    <div className={styles.staticRangesWrapper}>
      <div className={styles.staticRanges}>
        {staticRanges.map((staticRange, i) => {
          const { selectedRange, focusedRangeIndex } = getSelectedRange(ranges || [], staticRange);
          console.log('selectedRange, ', selectedRange, focusedRangeIndex);
          return (
            <StaticRangeButton
              key={i}
              onPreviewChange={onPreviewChange}
              rangeColors={rangeColors}
              renderStaticRangeLabel={renderStaticRangeLabel}
              selectedRange={selectedRange}
              focusedRangeIndex={focusedRangeIndex}
              staticRange={staticRange}
              handleRangeChange={usableHandleRangeChange}
            />
          );
        })}
        {staticRangeIndex === -1
          ? <span key={"custom-range"} className={styles.staticRangeCustomSelection}>Custom</span>
          : null
        }
      </div>
    </div>
  );
}

export default StaticRanges;
